@@ -12,7 +12,7 @@ from celery.worker import pidbox
 
 from .tasks import Tasks
 
-__all__ = ['Control']
+__all__ = ('Control',)
 
 logger = get_logger(__name__)
 
